from adminsortable2.admin import SortableInlineAdminMixin
from django.contrib import admin
#from .inline_select_action import BaseInlineSelectActionsMixin
from inline_actions.admin import InlineActionsMixin, InlineActionsModelAdminMixin 
from ..models.evaluation import EvaluationAttribute, Evaluation
from django.utils.translation import ugettext_lazy as _
from django.contrib import messages


class EvaluationAttributeInline(InlineActionsMixin, SortableInlineAdminMixin, admin.TabularInline):
    model = EvaluationAttribute
    extra = 0    
    list_display = (
        'sort', 'evaluation_attr_id', 'name', 'sex', 'age_min', 'age_max', 'value_min', 'value_max', 'evaluation_text')
    list_editable = ('sort', 'name', 'sex', 'age_min', 'age_max', 'value_min', 'value_max', 'evaluation_text')   
    list_display_links = ('sort', )
    ordering = ('sort',)
    inline_actions = ('clone_eval',)

    def clone_eval(self, request, obj, parent_obj=None):
        print("cloning {obj}")
        obj.pk = None
        obj.name = obj.name + "_copy"
        obj.save()
        messages.info(request, f'{obj} has been cloned')
    
    clone_eval.short_description = _("Clone the selected evaluation")


class EvaluationAdmin(InlineActionsModelAdminMixin, admin.ModelAdmin):
    list_display = ('evaluation_id', 'name', 'get_exercise_type')

    def get_exercise_type(self, obj):
        return obj.exercise_type.name

    inlines = [
        EvaluationAttributeInline
    ]        


admin.site.register(Evaluation, EvaluationAdmin)
admin.autodiscover()
