from django.db import models
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _

from .enums import LanguageTypes


class ExerciseDevice(models.Model):
    exercise_device_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100)
    image_url = models.ImageField(upload_to='images/', help_text='The image size is 1366x768')
    description = models.TextField(max_length=1000, blank=True, null=True, help_text="English description here")
    sort = models.IntegerField(blank=True, null=True)
    place = models.BooleanField()

    class Meta:
        db_table = 'exercise_device'
        verbose_name = _("Exercise Device")
        verbose_name_plural = _("Exercise Devices")
        ordering = ['name']

    def image_tag(self):
        return mark_safe('<img src="/media/%s" width="30%" height="30%" />' % self.image_url)

    image_tag.short_description = 'Image'

    def __str__(self):
        return self.name


class ExerciseDeviceAlternative(models.Model):
    exercise_device_alternative_id = models.AutoField(primary_key=True)
    exercise_device_parent = models.ForeignKey(ExerciseDevice, on_delete=models.CASCADE,
                                               related_name='exercise_device_parent')
    exercise_device_child = models.ForeignKey(ExerciseDevice, on_delete=models.CASCADE,
                                              related_name='exercise_device_child')

    class Meta:
        db_table = 'exercise_device_alternative'
        verbose_name = _("Device Alternative")
        verbose_name_plural = _("Device Alternatives")
        unique_together = ['exercise_device_parent', 'exercise_device_child']


class ExerciseDeviceTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    exercise_device = models.ForeignKey(ExerciseDevice, on_delete=models.CASCADE)
    name = models.CharField(max_length=100)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)

    class Meta:
        db_table = 'exercise_device_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name
